#
#    RedEye is a Disc Authoring and Burning program.
#    Copyright (C) 2003  Michael Urman
#
#    RedEye is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RedEye is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RedEye; if not, write to the Free Software Foundation, Inc., 59
#    Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import os
import gtk

pixmapprefix = [
    '/usr/share/redeye/pixmaps',
    '/usr/local/share/redeye/pixmaps',
    '/usr/share/pixmaps/redeye',
    '/usr/local/share/pixmaps/redeye',
]

for path in pixmapprefix[:]:
    if not os.path.exists(path):
        pixmapprefix.remove(path)

def findicon(icon):
    if icon is None:
        return
    for path in pixmapprefix:
        iconpath = os.path.join(path, icon)
        if os.path.exists(iconpath):
            return iconpath
    else:
        return os.path.join('.', 'pixmaps', icon)

stockicons = [
    ('disc', None, 'gtk-cdrom'),
    ('session', None, 'gtk-cdrom'),
    ('audio_track', 'icon-f-a.png', 'gtk-dnd'),
    ('data_track', 'icon-s-d.png', 'gtk-dnd-multiple'),

    ('audio_session', 'icon-s-a.png', 'gtk-cdrom'),
    ('virtual_dir', 'icon-d.png', 'gtk-open'),
    ('directory', 'icon-d-f.png', 'gtk-open'),
    ('data_file', None, 'gtk-new'),

    ('add_file', None, 'gtk-new'),
    ('remove_file', None, 'gtk-remove'),
    ('burn_cd', None, 'gtk-execute'),

    ('delete', None, 'gtk-delete'),
    ('prefs', None, 'gtk-preferences'),
    ('view_log', None, 'gtk-justify-left'),

    ('info', None, 'gtk-dialog-info'),
    ('warning', None, 'gtk-dialog-warning'),
    ('error', None, 'gtk-dialog-error'),
]

menuitems = [
    ('_File', None, [
        ('gtk-new', 'gtk-new', 'open'),
        ('gtk-open', 'gtk-open', 'open'),
        '---',
        ('_Describe', '', 'describe'),
        ('gtk-save', 'gtk-save', 'save'),
        ('gtk-save-as', 'gtk-save-as', 'save'),
        ('gtk-revert-to-saved', 'gtk-revert-to-saved', 'open'),
        '---',
        #('gtk-properties', 'gtk-properties', 'pref_prop'),
        #'---',
        ('gtk-close', 'gtk-close', 'close'),
        ('gtk-quit', 'gtk-quit', 'close'),
    ]),
    ('_Edit', None, [
        ('gtk-undo', 'gtk-undo', 'edit'),
        ('gtk-redo', 'gtk-redo', 'edit'),
        '---',
        ('gtk-cut', 'gtk-cut', 'edit'),
        ('gtk-copy', 'gtk-copy', 'edit'),
        ('gtk-paste', 'gtk-paste', 'edit'),
        ('gtk-delete', 'gtk-delete', 'edit'),
        '---',
        ('gtk-preferences', 'gtk-preferences', 'pref_prop'),
    ]),
    ('_View', None, [
        ('_Toolbar', bool, 'view'),
        ('_Statusbar', bool, 'view'),
        '---',
        ('_Messages...', 'gtk-dialog-info', 'view'),
        ('_Output Logs...', 'gtk-justify-left', 'view'),
    ]),
    ('_Insert', None, [
        ('_Session', 'gtk-cdrom', 'insert'),
        '---',
        ('_Audio Track', 'gtk-dnd', 'insert'),
        ('_Data Track', 'gtk-dnd-multiple', 'insert'),
        '---',
        ('Fo_lder', 'gtk-open', 'insert'),
        ('_File', 'gtk-new', 'insert'),
    ]),
    ('_Help', None, [
        ('gtk-help', 'gtk-help', 'help'),
        ('_About', 'gtk-dialog-info', 'help'),
    ]),
]


toolbaritems = [
    ('add_session', 'Session', 'session',
        'Add a new Session to your Layout'),
    '----',
    ('add_data_track', 'Data Track', 'data_track',
        'Add a new Data Track to your Layout'),
    ('add_audio_track', 'Audio Track', 'audio_track',
        'Add a new Audio Track to your Layout'),
    '----',
    ('add_dir', 'Add Folder', 'virtual_dir',
        'Add a new Folder to your Layout'),
    ('add_files', 'Add File(s)', 'add_file',
        'Add one or more Files to your Layout'),
    '----',
    ('delete_selected', 'Remove', 'delete',
        'Remove selected items from your Layout'),
    '----',
    #('prefs', 'Preferences', 'prefs',
        #'Disc Recording Preferences'),
    #'----',
    ('burn', 'Write Disc', 'burn_cd',
        'Write the Disc described by your Layout'),
    #'----',
    #('info', 'Info', 'info', 'Insert a test info'),
    #('warn', 'Info', 'warning', 'Insert a test warning'),
    #('error', 'Info', 'error', 'Insert a test error'),
]

pixbuf = {}
def render_icons():
    """Render icons for use in RedEye"""

    for key, src, fallback in stockicons:
        if key in pixbuf: continue
        srcpath = findicon(src)

        # try to use provided alternate icons
        if src and os.path.exists(srcpath):
            img = gtk.gdk.pixbuf_new_from_file(srcpath)
            iconset = gtk.IconSet(img)
            img_toolbar = gtk.Image()
            img_toolbar.set_from_icon_set(iconset, gtk.ICON_SIZE_LARGE_TOOLBAR)
            img_menu = gtk.Image()
            img_menu.set_from_icon_set(iconset, gtk.ICON_SIZE_MENU)
        else:   # but fall back to stock icons that mostly fit
            iconset = None
            img_toolbar = gtk.image_new_from_stock(fallback, gtk.ICON_SIZE_LARGE_TOOLBAR)
            img_menu = gtk.image_new_from_stock(fallback, gtk.ICON_SIZE_MENU)
        pixbuf[key] = img_menu, img_toolbar, iconset

def filesize(bytes):
    cutoffs = ((10, 'K'), (20, 'M'), (30, 'G'), (40, 'T'))
    if bytes < 1000:
        return str(bytes) + 'B'
    for exp, suffix in cutoffs:
        if bytes < 1000*2**exp:
            size = bytes/2.0**exp
            if size < 10:
                return '%.2f%s' % (size, suffix)
            else:
                return '%.1f%s' % (size, suffix)
    else:
        return u'\u221e'    # Infinity (sure it's a lie)

