#
#    RedEye is a Disc Authoring and Burning program.
#    Copyright (C) 2003  Michael Urman
#
#    RedEye is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RedEye is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RedEye; if not, write to the Free Software Foundation, Inc., 59
#    Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

from RedEye.Helper import Helper

class Mkisofs(Helper.program):

    rock_ridge = True

    def __init__(self):
        super(mkisofs, self).__init__('mkisofs')
        self.files = []

    params = [
        ('-A%s', 'application_id', 1, 128, None,
            "Describe this disc's application"),
        ('-b%s', 'eltorito_image', 1, None, None,
            "Pathname of 1200, 1440, or 2880 kB image"),
        ('-C%s', 'multisession_info', 1, None, None,
            'Session start information from "cdrecord -msinfo"'),
        ('-P%s', 'publisher_id', 1, 128, None,
            "Publisher of the disc, usually with mail address and phone"),
        ('-p%s', 'preparer_id', 1, 128, None,
            "Preparer of the disc, usually with mail address and phone"),
        ('-V%s', 'volume_id', 1, 32, None,
            "Volume name / label; mount point for Solaris"),
        ('-M%s', 'merge_session_path', 1, None, None,
            "Path to the existing sesion for inclusive multi-session"),
        ('-o%s', 'output_filename', 1, None, None,
            "Output filename for saving ISO image"),

        ('-J', 'joliet_records', 0, None, True,
            "Generate Joliet directory records, limited to 64 UTF-16 chars"),
        ('-f', 'follow_symlinks', 0, None, True,
            "Follow symbolic links; otherwise Rock Ridge links, or ignored"),
        ('-l', 'thirtyone_chars', 0, None, False,
            "Allow 31 character filenames; bad for MS-DOS compatibility"),
        ('-L', 'leading_dot', 0, None, False,
            "Allow filenames to begin with a period instead of underscore"),
        ('-print-size', 'print_size', 0, None, False,
            "Used internally to detect size for TAO burns"),
        ('-R', 'rock_ridge_direct_perms', 0, None, False,
            "Use Rock Ridge format with permissions as on files"),
        ('-r', 'rock_ridge', 0, None, True,
            "Use Rock Ridge format with sanitized (uid=0 755/644) permissions"),
    ]

    def command(self):
        if self.binary is None:
            raise ValueError('%s could not be found in your $PATH' % self.binary_name)
        args = [self.binary]

        for arg, attr, takes_arg, length, default, description in self.params:
            if takes_arg:
                if hasattr(self, attr):
                    args.append(arg % getattr(self, attr))
            else:
                if hasattr(self, attr):
                    if getattr(self, attr):
                        args.append(arg)
                else:
                    if default:
                        args.append(arg)

        args.append('-graft-points')
        args.append('-gui')

        args.append('--')
        for fname, forig in self.files:
            args.append('%s=%s' % (
                fname.replace('\\', '\\\\').replace('=', '\\='),
                forig.replace('\\', '\\\\').replace('=', '\\=')))

        return tuple(args)

    def get_image_size(self):
        self.print_size = True
        out = self.run_stdout().read().strip()
        del self.print_size
        try:
            return int(out) * 2048
        except ValueError:
            raise RuntimeError('Unexpected size reporting "%s"' % out)
