#
#    RedEye is a Disc Authoring and Burning program.
#    Copyright (C) 2003  Michael Urman
#
#    RedEye is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    RedEye is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with RedEye; if not, write to the Free Software Foundation, Inc., 59
#    Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import gtk
from RedEye import Config

class Row(object):
    icon = None

    container_types = None

    is_sized = False
    is_removable = True
    is_root = False

    is_editable = False
    model_iter = None

    popup = None
    size = 0

    def __init__(self, name, view, source=None):
        self.name = name
        self.source = source
        self.children = []

        if not isinstance(self.icon, gtk.gdk.Pixbuf):
            # Load Icon
            v = Config.pixbuf[self.icon]
            if v[2] is None:
                stockid, size = v[0].get_stock()
                icon = view.render_icon(stockid, size)
            else:
                icon = v[2].render_icon(view.get_style(), gtk.TEXT_DIR_NONE,
                    gtk.STATE_NORMAL, gtk.ICON_SIZE_MENU, view, None)
            self.__class__.icon = icon

        if self.popup is not None and not isinstance(self.popup, gtk.Menu):
            menu = gtk.Menu()
            view.populate_submenu(menu, self.popup)
            self.popup = menu

    def get_size(self):
        return self.size
    def set_size(self, iter, size):
        self.size = size
        model = self.view.model
        model.row_changed(model.get_path(iter), iter)
    def add_size(self, iter, size):
        return self.set_size(iter, self.size + size)

    def get_name(self):
        return self.name
    def set_name(self, name):
        self.name = name

    def __str__(self):
        return '%s %s' % (self.__class__.__name__, repr(self.get_name()))

    def __repr__(self):
        if self.source is None:
            return '<%s %s>' % (self.__class__.__name__, repr(self.get_name()))
        else:
            return '<%s %s=%s>' % (self.__class__.__name__, repr(self.get_name()), repr(self.source))

    def describe(self, progeny):
        children = []
        for child, grandchildren in progeny:
            children.append(child.describe(grandchildren))
        return self, children

    def can_go_in(self, obj):
        return obj is not None and isinstance(obj, self.container_types)

class Root(Row):
    is_removable = False
    is_root = True

class Session(Row):
    is_removable = True
    is_session = True
    container_types = Root

class Track(Row):
    is_removable = True
    is_track = True
    container_types = Session

class File(Row):
    is_editable = True
    argument = None

class Folder(File):
    is_editable = True
    default_name = 'Folder'

File.container_types = Folder, Track
Folder.container_types = Folder, Track
